@@ -28,7 +28,9 @@ from zope.publisher.interfaces import NotFound
 from zope.ramcache.interfaces.ram import IRAMCache
 
 import datetime
+from operator import itemgetter
 import re
+import six
 
 
 # Borrowed from zope.schema to avoid an import of a private name
@@ -126,7 +128,7 @@ class ControlPanel(BaseView):
                     self.context,
                     self.request,
                     self.editOperationName,
-                    operation
+                    operation,
                 )
             elif self.editRuleset:
                 return self  # traverse again to get ruleset name
@@ -163,8 +165,8 @@ class ControlPanel(BaseView):
             elif 'form.button.Cancel' in self.request.form:
                 self.request.response.redirect(
                     '{0}/@@overview-controlpanel'.format(
-                        self.context.absolute_url()
-                    )
+                        self.context.absolute_url(),
+                    ),
                 )
 
     def processSave(self):
@@ -200,10 +202,10 @@ class ControlPanel(BaseView):
             if not ruleset or not operation:
                 continue
 
-            if isinstance(ruleset, unicode):  # should be ASCII
+            if isinstance(ruleset, six.text_type):  # should be ASCII
                 ruleset = ruleset.encode('utf-8')
 
-            if isinstance(operation, unicode):  # should be ASCII
+            if isinstance(operation, six.text_type):  # should be ASCII
                 operation = operation.encode('utf-8')
 
             ruleset = ruleset.replace('-', '.')
@@ -213,7 +215,7 @@ class ControlPanel(BaseView):
             if not ruleset:
                 continue
 
-            if isinstance(ruleset, unicode):  # should be ASCII
+            if isinstance(ruleset, six.text_type):  # should be ASCII
                 ruleset = ruleset.encode('utf-8')
 
             ruleset = ruleset.replace('-', '.')
@@ -221,24 +223,24 @@ class ControlPanel(BaseView):
                 if not contentType:
                     continue
 
-                if isinstance(contentType, unicode):  # should be ASCII
+                if isinstance(contentType, six.text_type):  # should be ASCII
                     contentType = contentType.encode('utf-8')
 
                 if contentType in contentTypeRulesetMapping:
                     self.errors.setdefault(
-                        'contenttypes', {}
+                        'contenttypes', {},
                     )[ruleset] = _(
                         u'Content type ${contentType} is already mapped to '
                         u'the rule ${ruleset}.',
                         mapping={
                             'contentType': self.contentTypesLookup.get(
-                                contentType, {}
+                                contentType, {},
                             ).get(
                                 'title',
-                                contentType
+                                contentType,
                             ),
-                            'ruleset': contentTypeRulesetMapping[contentType]
-                        }
+                            'ruleset': contentTypeRulesetMapping[contentType],
+                        },
                     )
                 else:
                     contentTypeRulesetMapping[contentType] = ruleset
@@ -247,7 +249,7 @@ class ControlPanel(BaseView):
             if not ruleset:
                 continue
 
-            if isinstance(ruleset, unicode):  # should be ASCII
+            if isinstance(ruleset, six.text_type):  # should be ASCII
                 ruleset = ruleset.encode('utf-8')
 
             ruleset = ruleset.replace('-', '.')
@@ -256,19 +258,19 @@ class ControlPanel(BaseView):
                 if not template:
                     continue
 
-                if isinstance(template, unicode):  # should be ASCII
+                if isinstance(template, six.text_type):  # should be ASCII
                     template = template.encode('utf-8')
 
                 if template in templateRulesetMapping:
                     self.errors.setdefault(
-                        'templates', {}
+                        'templates', {},
                     )[ruleset] = _(
                         u'Template ${template} is already mapped to the rule '
                         u'${ruleset}.',
                         mapping={
                             'template': template,
-                            'ruleset': templateRulesetMapping[template]
-                        }
+                            'ruleset': templateRulesetMapping[template],
+                        },
                     )
                 else:
                     templateRulesetMapping[template] = ruleset
@@ -282,7 +284,7 @@ class ControlPanel(BaseView):
             if not _isuri(domain):
                 self.errors['domain'] = _(
                     u'Invalid URL: ${url}',
-                    mapping={'url': domain}
+                    mapping={'url': domain},
                 )
 
         # RAM cache settings
@@ -293,7 +295,7 @@ class ControlPanel(BaseView):
         else:
             if ramCacheMaxEntries < 0:
                 self.errors['ramCacheMaxEntries'] = _(
-                    u'A positive number is required.'
+                    u'A positive number is required.',
                 )
         try:
             ramCacheMaxAge = int(ramCacheMaxAge)
@@ -302,19 +304,19 @@ class ControlPanel(BaseView):
         else:
             if ramCacheMaxAge < 0:
                 self.errors['ramCacheMaxAge'] = _(
-                    u'A positive number is required.'
+                    u'A positive number is required.',
                 )
 
         try:
             ramCacheCleanupInterval = int(ramCacheCleanupInterval)
         except (ValueError, TypeError,):
             self.errors['ramCacheCleanupInterval'] = _(
-                u'An integer is required.'
+                u'An integer is required.',
             )
         else:
             if ramCacheMaxAge < 0:
                 self.errors['ramCacheCleanupInterval'] = _(
-                    u'A positive number is required.'
+                    u'A positive number is required.',
                 )
 
         # Check for errors
@@ -339,12 +341,12 @@ class ControlPanel(BaseView):
         self.ramCache.update(
             ramCacheMaxEntries,
             ramCacheMaxAge,
-            ramCacheCleanupInterval
+            ramCacheCleanupInterval,
         )
 
         IStatusMessage(self.request).addStatusMessage(
             _(u'Changes saved.'),
-            'info'
+            'info',
         )
 
     # Rule types - used as the index column
@@ -356,8 +358,8 @@ class ControlPanel(BaseView):
             types.append(dict(name=type_.name,
                               title=type_.title or type_.name,
                               description=type_.description,
-                              safeName=type_.name.replace('.', '-')))
-        types.sort(lambda x, y: cmp(x['title'], y['title']))
+                              safeName=type_.name.replace('.', '-'), ))
+        types.sort(key=itemgetter('title'))
         return types
 
     # Safe access to the main mappings, which may be None - we want to treat
@@ -368,7 +370,7 @@ class ControlPanel(BaseView):
     def operationMapping(self):
         return dict(
             [(k.replace('.', '-'), v,)
-             for k, v in (self.settings.operationMapping or {}).items()]
+             for k, v in (self.settings.operationMapping or {}).items()],
         )
 
     @property
@@ -379,7 +381,7 @@ class ControlPanel(BaseView):
                 for k, v in (
                     self.ploneSettings.templateRulesetMapping or {}
                 ).items()
-            ]
+            ],
         )
 
     @property
@@ -390,7 +392,7 @@ class ControlPanel(BaseView):
                 for k, v in (
                     self.ploneSettings.contentTypeRulesetMapping or {}
                 ).items()
-            ]
+            ],
         )
 
     # Type lookups (for accessing settings)
@@ -419,7 +421,7 @@ class ControlPanel(BaseView):
         portal_types = getToolByName(self.context, 'portal_types')
         for fti in portal_types.objectValues():
             types[fti.id] = dict(title=fti.title or fti.id,
-                                 description=fti.description)
+                                 description=fti.description, )
         return types
 
     # Sorted lists (e.g. for drop-downs)
@@ -428,8 +430,7 @@ class ControlPanel(BaseView):
     @memoize
     def operationTypes(self):
         operations = [v for k, v in self.operationTypesLookup.items()]
-        operations.sort(lambda x, y: (
-            cmp(x['sort'], y['sort']) or cmp(x['title'], y['title'])))
+        operations.sort(key=lambda operation:(operation['sort'], operation['title']))
         return operations
 
     @property
@@ -439,10 +440,10 @@ class ControlPanel(BaseView):
             dict(
                 name=name,
                 title=info['title'],
-                description=info['description']
+                description=info['description'],
             ) for name, info in self.contentTypesLookup.items()
         ]
-        types.sort(lambda x, y: cmp(x['title'], y['title']))
+        types.sort(key=itemgetter('title'))
         return types
 
     # We store template and content type mappings as template -> ruleset and
@@ -492,7 +493,7 @@ class ControlPanel(BaseView):
             return False
 
         for option in options:
-            if '{0}.{1}.{2}'.format(prefix, ruleset, option,) in self.registry:
+            if '{0}.{1}.{2}'.format(prefix, ruleset, option) in self.registry:
                 return True
 
         return False
@@ -529,11 +530,11 @@ class Import(BaseView):
 
         # Import the new profile
         portal_setup.runAllImportStepsFromProfile(
-            'profile-{0}'.format(profile)
+            'profile-{0}'.format(profile),
         )
 
         IStatusMessage(self.request).addStatusMessage(
-            _(u'Import complete.'), 'info')
+            _(u'Import complete.'), 'info'),
 
     @property
     @memoize
