@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-from cStringIO import StringIO
 from plone.app.caching.interfaces import IPloneCacheSettings
 from plone.app.caching.testing import PLONE_APP_CACHING_FUNCTIONAL_TESTING
 from plone.app.caching.tests.test_utils import stable_now
@@ -26,7 +25,8 @@ import dateutil.parser
 import dateutil.tz
 import os
 import pkg_resources
-import unittest2 as unittest
+import six
+import unittest
 
 
 TEST_FILE = pkg_resources.resource_filename(
@@ -39,8 +39,8 @@ def test_image():
         'plone.app.caching.tests', 'test.gif')
     filename = os.path.join(os.path.dirname(__file__), u'test.gif')
     return NamedBlobImage(
-        data=open(filename, 'r').read(),
-        filename=filename
+        data=open(filename, 'rb').read(),
+        filename=filename,
     )
 
 
@@ -89,7 +89,7 @@ class TestProfileWithCaching(unittest.TestCase):
     def tearDown(self):
         setRequest(None)
 
-    def test_composite_views(self):
+    def test_composite_viewsxx(self):
         # This is a clone of the same test for 'without-caching-proxy'
         # Can we just call that test from this context?
 
@@ -100,18 +100,18 @@ class TestProfileWithCaching(unittest.TestCase):
         setRoles(self.portal, TEST_USER_ID, ('Manager',))
         self.portal.invokeFactory('Folder', 'f1')
         self.portal['f1'].title = 'one'
-        self.portal['f1'].description = u"Folder one description"
+        self.portal['f1'].description = u'Folder one description'
         self.portal['f1'].reindexObject()
 
         # Add page content
         self.portal['f1'].invokeFactory('Document', 'd1')
-        self.portal['f1']['d1'].title = u"Document one"
-        self.portal['f1']['d1'].description = u"Document one description"
+        self.portal['f1']['d1'].title = u'Document one'
+        self.portal['f1']['d1'].description = u'Document one description'
         testText = 'Testing... body one'
         self.portal['f1']['d1'].text = RichTextValue(
             testText,
             'text/plain',
-            'text/html'
+            'text/html',
         )
         self.portal['f1']['d1'].reindexObject()
 
@@ -149,7 +149,7 @@ class TestProfileWithCaching(unittest.TestCase):
                          browser.headers['Cache-Control'])
         self.assertEqual('"|test_user_1_|%d|en|%s|0|0' % (catalog.getCounter(
         ), skins_tool.default_skin), _normalize_etag(browser.headers['ETag']))
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
         # Set the copy/cut cookie and then request the folder view again
@@ -173,7 +173,7 @@ class TestProfileWithCaching(unittest.TestCase):
             'Basic {0}:{1}'.format(TEST_USER_NAME, TEST_USER_PASSWORD, ),
         )
         browser.open(self.portal['f1']['d1'].absolute_url())
-        self.assertTrue(testText in browser.contents)
+        self.assertIn(testText, browser.contents)
         self.assertEqual('plone.content.itemView',
                          browser.headers['X-Cache-Rule'])
         self.assertEqual('plone.app.caching.weakCaching',
@@ -183,7 +183,7 @@ class TestProfileWithCaching(unittest.TestCase):
                          browser.headers['Cache-Control'])
         self.assertEqual('"|test_user_1_|%d|en|%s|0' % (catalog.getCounter(
         ), skins_tool.default_skin), _normalize_etag(browser.headers['ETag']))
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
         # Request the authenticated page again -- to test RAM cache.
@@ -198,7 +198,7 @@ class TestProfileWithCaching(unittest.TestCase):
         self.assertEqual('plone.app.caching.weakCaching',
                          browser.headers['X-Cache-Operation'])
         # Authenticated should NOT be RAM cached
-        self.assertEqual(None, browser.headers.get('X-RAMCache'))
+        self.assertIsNone(browser.headers.get('X-RAMCache'))
 
         # Request the authenticated page again -- with an INM header to test
         # 304
@@ -213,11 +213,12 @@ class TestProfileWithCaching(unittest.TestCase):
         browser.open(self.portal['f1']['d1'].absolute_url())
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertEqual('', browser.contents)
+        self.assertEqual(b'', browser.contents)
 
         # Request the anonymous folder
         now = stable_now()
         browser = Browser(self.app)
+        browser.handleErrors = False
         browser.open(self.portal['f1'].absolute_url())
         self.assertEqual('plone.content.folderView',
                          browser.headers['X-Cache-Rule'])
@@ -228,7 +229,7 @@ class TestProfileWithCaching(unittest.TestCase):
                          browser.headers['Cache-Control'])
         self.assertEqual('"||%d|en|%s|0|0' % (catalog.getCounter(
         ), skins_tool.default_skin), _normalize_etag(browser.headers['ETag']))
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
         # Request the anonymous page
@@ -239,13 +240,13 @@ class TestProfileWithCaching(unittest.TestCase):
                          browser.headers['X-Cache-Rule'])
         self.assertEqual('plone.app.caching.weakCaching',
                          browser.headers['X-Cache-Operation'])
-        self.assertTrue(testText in browser.contents)
+        self.assertIn(testText, browser.contents)
         # This should use cacheInBrowser
         self.assertEqual('max-age=0, must-revalidate, private',
                          browser.headers['Cache-Control'])
         self.assertEqual('"||%d|en|%s|0' % (catalog.getCounter(
         ), skins_tool.default_skin), _normalize_etag(browser.headers['ETag']))
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
         # Request the anonymous page again -- to test RAM cache.
@@ -260,12 +261,12 @@ class TestProfileWithCaching(unittest.TestCase):
         # This should come from RAM cache
         self.assertEqual('plone.app.caching.operations.ramcache',
                          browser.headers['X-RAMCache'])
-        self.assertTrue(testText in browser.contents)
+        self.assertIn(testText, browser.contents)
         self.assertEqual('max-age=0, must-revalidate, private',
                          browser.headers['Cache-Control'])
         self.assertEqual('"||%d|en|%s|0' % (catalog.getCounter(
         ), skins_tool.default_skin), _normalize_etag(browser.headers['ETag']))
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
         # Request the anonymous page again -- with an INM header to test 304.
@@ -280,14 +281,14 @@ class TestProfileWithCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertEqual('', browser.contents)
+        self.assertEqual(b'', browser.contents)
 
         # Edit the page to update the etag
         testText2 = 'Testing... body two'
         self.portal['f1']['d1'].text = RichTextValue(
             testText2,
             'text/plain',
-            'text/html'
+            'text/html',
         )
         self.portal['f1']['d1'].reindexObject()
 
@@ -305,8 +306,8 @@ class TestProfileWithCaching(unittest.TestCase):
         self.assertEqual('plone.app.caching.weakCaching',
                          browser.headers['X-Cache-Operation'])
         # The etag has changed so we should get a fresh page.
-        self.assertEqual(None, browser.headers.get('X-RAMCache'))
-        self.assertEqual('200 Ok', browser.headers['Status'])
+        self.assertIsNone(browser.headers.get('X-RAMCache'))
+        self.assertEqual('200 OK', browser.headers['Status'].upper())
 
     def test_content_feeds(self):
 
@@ -337,7 +338,7 @@ class TestProfileWithCaching(unittest.TestCase):
             skins_tool.default_skin,
         )
         self.assertEqual(tag, browser.headers['ETag'])
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
         # Request the rss feed again -- to test RAM cache
@@ -359,7 +360,7 @@ class TestProfileWithCaching(unittest.TestCase):
             skins_tool.default_skin,
         )
         self.assertEqual(tag, browser.headers['ETag'])
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
         # Request the rss feed again -- with an INM header to test 304.
@@ -373,7 +374,7 @@ class TestProfileWithCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertEqual('', browser.contents)
+        self.assertEqual(b'', browser.contents)
 
         # Request the authenticated rss feed
         now = stable_now()
@@ -394,7 +395,7 @@ class TestProfileWithCaching(unittest.TestCase):
             skins_tool.default_skin,
         )
         self.assertEqual(tag, browser.headers['ETag'])
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
         # Request the authenticated rss feed again -- to test RAM cache
@@ -408,21 +409,21 @@ class TestProfileWithCaching(unittest.TestCase):
         self.assertEqual('plone.app.caching.moderateCaching',
                          browser.headers['X-Cache-Operation'])
         # Authenticated should NOT be RAM cached
-        self.assertEqual(None, browser.headers.get('X-RAMCache'))
+        self.assertIsNone(browser.headers.get('X-RAMCache'))
 
     def test_content_files(self):
 
         # Add folder content
         setRoles(self.portal, TEST_USER_ID, ('Manager',))
         self.portal.invokeFactory('Folder', 'f1')
-        self.portal['f1'].title = u"Folder one"
-        self.portal['f1'].description = u"Folder one description"
+        self.portal['f1'].title = u'Folder one'
+        self.portal['f1'].description = u'Folder one description'
         self.portal['f1'].reindexObject()
 
         # Add content image
         self.portal['f1'].invokeFactory('Image', 'i1')
-        self.portal['f1']['i1'].title = u"Image one"
-        self.portal['f1']['i1'].description = u"Image one description"
+        self.portal['f1']['i1'].title = u'Image one'
+        self.portal['f1']['i1'].description = u'Image one description'
         self.portal['f1']['i1'].image = test_image()
         self.portal['f1']['i1'].reindexObject()
 
@@ -446,7 +447,7 @@ class TestProfileWithCaching(unittest.TestCase):
                          browser.headers['Cache-Control'])
         # remove this when the next line works
         self.assertIsNotNone(browser.headers.get('Last-Modified'))
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
         # Request an image scale with Manager role
@@ -468,7 +469,7 @@ class TestProfileWithCaching(unittest.TestCase):
                          browser.headers['Cache-Control'])
         # remove this when the next line works
         self.assertIsNotNone(browser.headers.get('Last-Modified'))
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
         # Publish the folder
@@ -489,7 +490,7 @@ class TestProfileWithCaching(unittest.TestCase):
                          browser.headers['Cache-Control'])
         # remove this when the next line works
         self.assertIsNotNone(browser.headers.get('Last-Modified'))
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
         # Request the image again -- with an IMS header to test 304
@@ -503,7 +504,7 @@ class TestProfileWithCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertEqual('', browser.contents)
+        self.assertEqual(b'', browser.contents)
 
         # Request an image scale
         now = stable_now()
@@ -518,7 +519,7 @@ class TestProfileWithCaching(unittest.TestCase):
                          browser.headers['Cache-Control'])
         # remove this when the next line works
         self.assertIsNotNone(browser.headers.get('Last-Modified'))
-        self.assertTrue(now > dateutil.parser.parse(
+        self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
 
     def test_resources(self):
@@ -541,7 +542,7 @@ class TestProfileWithCaching(unittest.TestCase):
         # remove this when the next line works
         self.assertIsNotNone(browser.headers.get('Last-Modified'))
         timedelta = dateutil.parser.parse(browser.headers['Expires']) - now
-        self.assertTrue(timedelta > datetime.timedelta(seconds=86390))
+        self.assertGreater(timedelta, datetime.timedelta(seconds=86390))
 
         # Request the skin image again -- with an IMS header to test 304
         lastmodified = browser.headers['Last-Modified']
@@ -554,7 +555,7 @@ class TestProfileWithCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertEqual('', browser.contents)
+        self.assertEqual(b'', browser.contents)
 
         # Request a large datafile (over 64K) to test files that use
         # the "response.write()" function to initiate a streamed response.
@@ -562,9 +563,11 @@ class TestProfileWithCaching(unittest.TestCase):
         # large OFS.Image.Image, large non-blog ATImages/ATFiles, and
         # large Resource Registry cooked files, which all use the same
         # method to initiate a streamed response.
-        s = 'a' * (1 << 16) * 3
-        self.portal.manage_addFile('bigfile', file=StringIO(
-            s), content_type='application/octet-stream')
+        s = b'a' * (1 << 16) * 3
+        self.portal.manage_addFile(
+            'bigfile',
+            file=six.BytesIO(s),
+            content_type='application/octet-stream')
 
         import transaction
         transaction.commit()
@@ -580,7 +583,7 @@ class TestProfileWithCaching(unittest.TestCase):
         # remove this when the next line works
         self.assertIsNotNone(browser.headers.get('Last-Modified'))
         timedelta = dateutil.parser.parse(browser.headers['Expires']) - now
-        self.assertTrue(timedelta > datetime.timedelta(seconds=86390))
+        self.assertGreater(timedelta, datetime.timedelta(seconds=86390))
 
     def test_stable_resources(self):
         # This is a clone of the same test for 'without-caching-proxy'
